package cn.com.infosec.x509;

import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Object;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.x509.GeneralName;
import cn.com.infosec.asn1.x509.Target;
import cn.com.infosec.asn1.x509.TargetInformation;
import cn.com.infosec.asn1.x509.Targets;
import cn.com.infosec.asn1.x509.X509Extensions;
import cn.com.infosec.util.Selector;
import java.io.IOException;
import java.math.BigInteger;
import java.security.cert.CertificateExpiredException;
import java.security.cert.CertificateNotYetValidException;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

public class X509AttributeCertStoreSelector implements Selector {
   private AttributeCertificateHolder holder;
   private AttributeCertificateIssuer issuer;
   private BigInteger serialNumber;
   private Date attributeCertificateValid;
   private X509AttributeCertificate attributeCert;
   private Collection targetNames;
   private Collection targetGroups;

   public X509AttributeCertStoreSelector() {
      X509AttributeCertStoreSelector var10000 = this;
      X509AttributeCertStoreSelector var10001 = this;
      super();
      HashSet var1;
      var1 = new HashSet.<init>();
      var10001.targetNames = var1;
      var1 = new HashSet.<init>();
      var10000.targetGroups = var1;
   }

   private Set extractGeneralNames(Collection names) {
      if (names != null && !names.isEmpty()) {
         HashSet var3;
         var3 = new HashSet.<init>();
         Iterator names1 = names.iterator();

         while(names1.hasNext()) {
            Object var2;
            if ((var2 = names1.next()) instanceof GeneralName) {
               var3.add(var2);
            } else {
               var3.add(GeneralName.getInstance(ASN1Object.fromByteArray((byte[])var2)));
            }
         }

         return var3;
      } else {
         return new HashSet();
      }
   }

   public boolean match(Object obj) {
      if (!(obj instanceof X509AttributeCertificate)) {
         return false;
      } else {
         X509AttributeCertificate obj1 = (X509AttributeCertificate)obj;
         X509AttributeCertificate var2;
         if ((var2 = this.attributeCert) != null && !var2.equals(obj1)) {
            return false;
         } else if (this.serialNumber != null && !obj1.getSerialNumber().equals(this.serialNumber)) {
            return false;
         } else if (this.holder != null && !obj1.getHolder().equals(this.holder)) {
            return false;
         } else if (this.issuer != null && !obj1.getIssuer().equals(this.issuer)) {
            return false;
         } else {
            Date var13;
            if ((var13 = this.attributeCertificateValid) != null) {
               try {
                  obj1.checkValidity(var13);
               } catch (CertificateExpiredException var8) {
                  return false;
               } catch (CertificateNotYetValidException var9) {
                  return false;
               }
            }

            byte[] obj2;
            if ((!this.targetNames.isEmpty() || !this.targetGroups.isEmpty()) && (obj2 = obj1.getExtensionValue(X509Extensions.TargetInformation.getId())) != null) {
               X509AttributeCertStoreSelector var10000;
               TargetInformation var10001;
               try {
                  var10000 = this;
                  var10001 = TargetInformation.getInstance((new ASN1InputStream(((DEROctetString)ASN1Object.fromByteArray(obj2)).getOctets())).readObject());
               } catch (IOException var6) {
                  return false;
               } catch (IllegalArgumentException var7) {
                  return false;
               }

               Targets[] obj3 = var10001.getTargetsObjects();
               int var3;
               Target[] var4;
               int var5;
               boolean var14;
               if (!var10000.targetNames.isEmpty()) {
                  var14 = false;
                  var3 = 0;

                  while(true) {
                     if (var3 >= obj3.length) {
                        if (!var14) {
                           return false;
                        }
                        break;
                     }

                     var4 = obj3[var3].getTargets();

                     for(var5 = 0; var5 < var4.length; ++var5) {
                        if (this.targetNames.contains(var4[var5].getTargetName())) {
                           var14 = true;
                           break;
                        }
                     }

                     ++var3;
                  }
               }

               if (!this.targetGroups.isEmpty()) {
                  var14 = false;

                  for(var3 = 0; var3 < obj3.length; ++var3) {
                     var4 = obj3[var3].getTargets();

                     for(var5 = 0; var5 < var4.length; ++var5) {
                        if (this.targetGroups.contains(var4[var5].getTargetGroup())) {
                           var14 = true;
                           break;
                        }
                     }
                  }

                  if (!var14) {
                     return false;
                  }
               }
            }

            return true;
         }
      }
   }

   public Object clone() {
      X509AttributeCertStoreSelector var1;
      X509AttributeCertStoreSelector var10000 = var1 = new X509AttributeCertStoreSelector;
      var1.<init>();
      var1.attributeCert = this.attributeCert;
      var1.attributeCertificateValid = this.getAttributeCertificateValid();
      var1.holder = this.holder;
      var1.issuer = this.issuer;
      var1.serialNumber = this.serialNumber;
      var1.targetGroups = this.getTargetGroups();
      var10000.targetNames = this.getTargetNames();
      return var10000;
   }

   public X509AttributeCertificate getAttributeCert() {
      return this.attributeCert;
   }

   public void setAttributeCert(X509AttributeCertificate attributeCert) {
      this.attributeCert = attributeCert;
   }

   public Date getAttributeCertificateValid() {
      return this.attributeCertificateValid != null ? new Date(this.attributeCertificateValid.getTime()) : null;
   }

   public void setAttributeCertificateValid(Date attributeCertificateValid) {
      if (attributeCertificateValid != null) {
         this.attributeCertificateValid = new Date(attributeCertificateValid.getTime());
      } else {
         this.attributeCertificateValid = null;
      }

   }

   public AttributeCertificateHolder getHolder() {
      return this.holder;
   }

   public void setHolder(AttributeCertificateHolder holder) {
      this.holder = holder;
   }

   public AttributeCertificateIssuer getIssuer() {
      return this.issuer;
   }

   public void setIssuer(AttributeCertificateIssuer issuer) {
      this.issuer = issuer;
   }

   public BigInteger getSerialNumber() {
      return this.serialNumber;
   }

   public void setSerialNumber(BigInteger serialNumber) {
      this.serialNumber = serialNumber;
   }

   public void addTargetName(GeneralName name) {
      this.targetNames.add(name);
   }

   public void addTargetName(byte[] name) {
      this.addTargetName(GeneralName.getInstance(ASN1Object.fromByteArray(name)));
   }

   public void setTargetNames(Collection names) {
      this.targetNames = this.extractGeneralNames(names);
   }

   public Collection getTargetNames() {
      return Collections.unmodifiableCollection(this.targetNames);
   }

   public void addTargetGroup(GeneralName group) {
      this.targetGroups.add(group);
   }

   public void addTargetGroup(byte[] name) {
      this.addTargetGroup(GeneralName.getInstance(ASN1Object.fromByteArray(name)));
   }

   public void setTargetGroups(Collection names) {
      this.targetGroups = this.extractGeneralNames(names);
   }

   public Collection getTargetGroups() {
      return Collections.unmodifiableCollection(this.targetGroups);
   }
}
